==> zio-aws-sagemakeredge_3-5.17.128.1-sources.jar: zio/aws/sagemakeredge/model/package.scala <==
package zio.aws.sagemakeredge
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.sagemakeredge.model.primitives.Metric.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object CacheTTLSeconds extends Subtype[String]
    type CacheTTLSeconds =
      zio.aws.sagemakeredge.model.primitives.CacheTTLSeconds.Type
    object DeviceFleetName extends Subtype[String]
    type DeviceFleetName =
      zio.aws.sagemakeredge.model.primitives.DeviceFleetName.Type
    object DeviceName extends Subtype[String]
    type DeviceName = zio.aws.sagemakeredge.model.primitives.DeviceName.Type
    object DeviceRegistration extends Subtype[String]
    type DeviceRegistration =
      zio.aws.sagemakeredge.model.primitives.DeviceRegistration.Type
    object Dimension extends Subtype[String]
    type Dimension = zio.aws.sagemakeredge.model.primitives.Dimension.Type
    object Metric extends Subtype[String]
    type Metric = zio.aws.sagemakeredge.model.primitives.Metric.Type
    object ModelName extends Subtype[String]
    type ModelName = zio.aws.sagemakeredge.model.primitives.ModelName.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.sagemakeredge.model.primitives.Timestamp.Type
    object Value extends Subtype[Double]
    type Value = zio.aws.sagemakeredge.model.primitives.Value.Type
    object Version extends Subtype[String]
    type Version = zio.aws.sagemakeredge.model.primitives.Version.Type
  }
  type EdgeMetrics = List[zio.aws.sagemakeredge.model.EdgeMetric]
  type Models = List[zio.aws.sagemakeredge.model.Model]
}

==> zio-aws-sagemakeredge_3-6.20.47.1-sources.jar: zio/aws/sagemakeredge/model/package.scala <==
package zio.aws.sagemakeredge
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.sagemakeredge.model.primitives.Metric.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object CacheTTLSeconds extends Subtype[String]
    type CacheTTLSeconds =
      zio.aws.sagemakeredge.model.primitives.CacheTTLSeconds.Type
    object ChecksumString extends Subtype[String]
    type ChecksumString =
      zio.aws.sagemakeredge.model.primitives.ChecksumString.Type
    object DeviceFleetName extends Subtype[String]
    type DeviceFleetName =
      zio.aws.sagemakeredge.model.primitives.DeviceFleetName.Type
    object DeviceName extends Subtype[String]
    type DeviceName = zio.aws.sagemakeredge.model.primitives.DeviceName.Type
    object DeviceRegistration extends Subtype[String]
    type DeviceRegistration =
      zio.aws.sagemakeredge.model.primitives.DeviceRegistration.Type
    object Dimension extends Subtype[String]
    type Dimension = zio.aws.sagemakeredge.model.primitives.Dimension.Type
    object EntityName extends Subtype[String]
    type EntityName = zio.aws.sagemakeredge.model.primitives.EntityName.Type
    object Metric extends Subtype[String]
    type Metric = zio.aws.sagemakeredge.model.primitives.Metric.Type
    object ModelName extends Subtype[String]
    type ModelName = zio.aws.sagemakeredge.model.primitives.ModelName.Type
    object S3Uri extends Subtype[String]
    type S3Uri = zio.aws.sagemakeredge.model.primitives.S3Uri.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.sagemakeredge.model.primitives.Timestamp.Type
    object Value extends Subtype[Double]
    type Value = zio.aws.sagemakeredge.model.primitives.Value.Type
    object Version extends Subtype[String]
    type Version = zio.aws.sagemakeredge.model.primitives.Version.Type
  }
  type Definitions = List[zio.aws.sagemakeredge.model.Definition]
  type DeploymentModels = List[zio.aws.sagemakeredge.model.DeploymentModel]
  type EdgeDeployments = List[zio.aws.sagemakeredge.model.EdgeDeployment]
  type EdgeMetrics = List[zio.aws.sagemakeredge.model.EdgeMetric]
  type Models = List[zio.aws.sagemakeredge.model.Model]
}
